testData

package
v1.7.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 14, 2022 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type TestData01

type TestData01 struct {
	// contains filtered or unexported fields
}

func (*TestData01) GetValidErrorPrefixDto

func (tData01 *TestData01) GetValidErrorPrefixDto() errpref.ErrPrefixDto

GetValidErrorPrefixDto - Returns a valid and fully populated instance of ErrPrefixDto for testing purposes.

func (*TestData01) GetValidErrorPrefixInfoArray

func (tData01 *TestData01) GetValidErrorPrefixInfoArray() []errpref.ErrorPrefixInfo

GetValidErrorPrefixInfoArray - Returns an array of Error Prefix Information objects for use in testing.

func (*TestData01) GetValidIBuilder

func (tData01 *TestData01) GetValidIBuilder() errpref.IBuilderErrorPrefix

func (*TestData01) GetValidTwoDStrArray

func (tData01 *TestData01) GetValidTwoDStrArray() [][2]string

GetValidTwoDStrArray - Returns a two-dimensional string array populated with error prefix information for use in testing.

func (*TestData01) Ptr

func (tData01 *TestData01) Ptr() *TestData01

ptr() - Returns a pointer to a new instance of TestData01.

Jump to