testFunctions

package
v1.7.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 14, 2022 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type TestFuncsDto

type TestFuncsDto struct{}

func (TestFuncsDto) Ptr added in v1.6.0

func (tFuncDto TestFuncsDto) Ptr() *TestFuncsDto

Ptr - Returns a pointer to a new instance of TestFuncsDto

func (TestFuncsDto) TestAlphaDto001

func (tFuncDto TestFuncsDto) TestAlphaDto001(
	returnExampleError bool,
	showExampleErrorMsg bool,
	callingMethodName string) error

TestAlphaDto001 This method calls the Alpha Series method chain with a two-dimensional array of strings.

An example error is only triggered on the last method in the chain if input parameter, 'returnExampleError' is set to 'true'.

If the input parameter 'returnExampleError' is set to 'true' and the input parameter 'showExampleErrorMsg' is set to true, this method will print the example error message to the terminal.

func (TestFuncsDto) TestBravoDto002 added in v1.6.0

func (tFuncDto TestFuncsDto) TestBravoDto002(
	returnExampleError bool,
	showExampleErrorMsg bool,
	maxLineLength int,
	callingMethodName string) error

TestBravoDto002 This method calls the Bravo Series method chain with an ErrPrefixDto object.

An example error is only triggered on the last method in the chain if input parameter, 'returnExampleError' is set to 'true'.

If the input parameter 'returnExampleError' is set to 'true' and the input parameter 'showExampleErrorMsg' is set to true, this method will print the example error message to the terminal.

Input parameter 'maxLineLength' is used to control the maximum line length of the error prefix information printed to the terminal. If this parameter is set to a value of minus one (-1), the default maximum line length will be applied. The current default maximum line length is 40-characters.

func (*TestFuncsDto) TestDelimiters005 added in v1.6.0

func (tFuncDto *TestFuncsDto) TestDelimiters005(
	returnExampleError bool,
	showExampleErrorMsg bool) error

func (*TestFuncsDto) TestIBuilder004 added in v1.6.0

func (tFuncDto *TestFuncsDto) TestIBuilder004(
	returnExampleError bool,
	showExampleErrorMsg bool) error

TestIBuilder004 - Demonstrates interoperability of the IBuilderErrorPrefix interface declared in the 'errpref' software package:

"github.com/MikeAustin71/errpref"

   type IBuilderErrorPrefix interface {
     GetEPrefStrings() [][2]string

     SetEPrefStrings(twoDStrArray [][2]string)

     String() string
   }

Type TestIBuilderErrPref implements the IBuilderErrorPrefix interface.

This method calls the Delta method chains with an ErrPrefixDto created from an IBuilderErrorPrefix object.

An example error is only triggered on the last method in the chain if input parameter, 'returnExampleError' is set to 'true'.

If the input parameter 'returnExampleError' is set to 'true' and the input parameter 'showExampleErrorMsg' is set to true, this method will print the example error message to the terminal.

This method sets the maximum line length for error prefix strings to 60-characters and does NOT implement a left margin.

func (TestFuncsDto) TestMethodSeries001

func (tFuncDto TestFuncsDto) TestMethodSeries001(
	returnExampleError bool,
	showExampleErrorMsg bool,
	callingMethodName string) error

TestMethodSeries001 - This method calls the Alpha, Bravo and Charlie method chains with an ErrPrefixDto object.

An example error is only triggered on the last method in the chain if input parameter, 'returnExampleError' is set to 'true'.

If the input parameter 'returnExampleError' is set to 'true' and the input parameter 'showExampleErrorMsg' is set to true, this method will print the example error message to the terminal.

This method relies on default maximum line length for error prefix strings and does NOT implement a left margin.

func (TestFuncsDto) TestMethodSeries002 added in v1.6.0

func (tFuncDto TestFuncsDto) TestMethodSeries002(
	returnExampleError bool,
	showExampleErrorMsg bool,
	callingMethodName string) error

TestMethodSeries002 - This method calls the Alpha, Bravo and Charlie method chains with an ErrPrefixDto object.

An example error is only triggered on the last method in the chain if input parameter, 'returnExampleError' is set to 'true'.

If the input parameter 'returnExampleError' is set to 'true' and the input parameter 'showExampleErrorMsg' is set to true, this method will print the example error message to the terminal.

This method sets the maximum line length for error prefix strings to 70-characters. It does NOT implement a left margin.

func (*TestFuncsDto) TestMethodSeries003 added in v1.6.0

func (tFuncDto *TestFuncsDto) TestMethodSeries003(c chan int, wg *sync.WaitGroup)

TestMethodSeries003 - This method calls the Alpha, Bravo and Charlie method chains with an ErrPrefixDto object.

An example error is only triggered on the last method in the chain if input parameter, 'returnExampleError' is set to 'true'.

This method will NOT print the example error message to the terminal.

THIS METHOD IS DESIGNED TO BE USED IN A CONCURRENCY EXAMPLE!

See mainTest003() in app/main.go

func (TestFuncsDto) TestMethodSeries004 added in v1.7.0

func (tFuncDto TestFuncsDto) TestMethodSeries004(
	returnExampleError bool,
	showExampleErrorMsg bool,
	callingMethodName string) error

TestMethodSeries004 - This method is designed to test the Leading and Trailing Text String feature implemented by type ErrPrefixDto.

This method/calls the Alpha, Bravo and Charlie method chains with an ErrPrefixDto object.

An example error is only triggered on the last method in the chain if input parameter, 'returnExampleError' is set to 'true'.

If the input parameter 'returnExampleError' is set to 'true' and the input parameter 'showExampleErrorMsg' is set to true, this method will print the example error message to the terminal.

This method sets the maximum line length for error prefix strings to 70-characters.

type TestFuncsStrings

type TestFuncsStrings struct{}

TestFuncsStrings - This type includes methods designed to test the string formatting capabilities of type, 'ErrPref'.

'ErrPref' is a simple, light-weight type used to receive error prefix strings, format them and return the formatted error prefix string immediately to the caller. No error prefix information is retained or maintained in the the 'ErrPref' object. It is simply used to format strings.

func (TestFuncsStrings) TestMethodSeries001

func (tFuncStrs TestFuncsStrings) TestMethodSeries001(callingMethodName string)

Jump to