Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TestFuncDtoAlpha01 ¶
type TestFuncDtoAlpha01 struct {
// contains filtered or unexported fields
}
TestFuncDtoAlpha01 - This type is designed to call a series of methods using Error Prefix Data Transfer Objects otherwise known as 'ErrPrefixDto'. For source code documentation on this type, reference:
https://pkg.go.dev/github.com/MikeAustin71/errpref#ErrPrefixDto
This method chain will return an error on the last function call, if, and only if, parameter, 'returnError' is set to 'true'.
The entry point for this method chain is:
TestFuncAlpha01.Tx1DoSomething()
These examples showcase the 'ErrPrefixDto' type and the use of an empty interface to initialize a new instance of 'ErrPrefixDto'.
For source code documentation on the 'ErrPrefixDto' type, reference:
https://pkg.go.dev/github.com/MikeAustin71/errpref#ErrPrefixDto
func (*TestFuncDtoAlpha01) Tx1DoSomething ¶
func (tFuncAlpha01 *TestFuncDtoAlpha01) Tx1DoSomething( returnError bool, errorPrefix interface{}) error
type TestFuncDtoBravo01 ¶
type TestFuncDtoBravo01 struct {
// contains filtered or unexported fields
}
TestFuncDtoBravo01 - This type is designed to call a series of methods using Error Prefix Data Transfer Objects otherwise known as 'ErrPrefixDto'. For source code documentation on this type, reference:
https://pkg.go.dev/github.com/MikeAustin71/errpref#ErrPrefixDto
This method chain will return an error on the last function call, if, and only if, parameter, 'returnError' is set to 'true'.
The entry point for this method chain is:
TestFuncBravo01.Tx1TrySomethingSpecial()
These examples showcase the 'ErrPrefixDto' type and the use of an empty interface to initialize a new instance of 'ErrPrefixDto'.
func (*TestFuncDtoBravo01) Tx1TrySomethingSpecial ¶ added in v1.6.0
func (tFuncDtoBravo01 *TestFuncDtoBravo01) Tx1TrySomethingSpecial( returnError bool, errorPrefix interface{}) error
type TestFuncDtoCharlie01 ¶
type TestFuncDtoCharlie01 struct {
// contains filtered or unexported fields
}
TestFuncDtoCharlie01 - This type is designed to call a series of methods using Error Prefix Data Transfer Objects otherwise known as 'ErrPrefixDto'. For source code documentation on this type, reference:
https://pkg.go.dev/github.com/MikeAustin71/errpref#ErrPrefixDto
This method chain will always return an error on the last function call.
The entry point for this method chain is:
TestFuncDtoCharlie01.Tx1DoStuff()
These examples showcase the 'ErrPrefixDto' type and the use of an empty interface to initialize a new instance of 'ErrPrefixDto'.
func (*TestFuncDtoCharlie01) Tx1DoStuff ¶
func (tFuncDtoCharlie01 *TestFuncDtoCharlie01) Tx1DoStuff( returnError bool, errorPrefix interface{}) error
type TestFuncDtoDelta01 ¶ added in v1.6.0
type TestFuncDtoDelta01 struct {
// contains filtered or unexported fields
}
TestFuncDtoDelta01 - This type is designed to call a series of methods using Error Prefix Data Transfer Objects otherwise known as 'ErrPrefixDto'. For source code documentation on this type, reference:
https://pkg.go.dev/github.com/MikeAustin71/errpref#ErrPrefixDto
This method chain will always return an error on the last function call.
The entry point for this method chain is:
TestFuncDtoDelta01.Tx1DoGreatThings()
These examples showcase the 'ErrPrefixDto' type and the use of an empty interface to initialize a new instance of 'ErrPrefixDto'.
func (*TestFuncDtoDelta01) Tx1DoGreatThings ¶ added in v1.6.0
func (tFuncDtoDelta01 *TestFuncDtoDelta01) Tx1DoGreatThings( returnError bool, errorPrefix interface{}) error
type TestFuncDtoEcho01 ¶ added in v1.6.0
type TestFuncDtoEcho01 struct {
// contains filtered or unexported fields
}
func (*TestFuncDtoEcho01) Tx1CreateSomething ¶ added in v1.6.0
func (tFuncDtoEcho01 *TestFuncDtoEcho01) Tx1CreateSomething( returnExampleError bool, oldErrPrefix string, inputDelimiters erPref.ErrPrefixDelimiters, outputDelimiters erPref.ErrPrefixDelimiters) error
type TestIBuilderErrPref ¶ added in v1.6.0
type TestIBuilderErrPref struct {
// contains filtered or unexported fields
}
TestIBuilderErrPref - Implements the IBuilderErrorPrefix interface declared in the 'errpref' software package
"github.com/MikeAustin71/errpref"
func (*TestIBuilderErrPref) GetEPrefStrings ¶ added in v1.6.0
func (tIBuilder *TestIBuilderErrPref) GetEPrefStrings() [][2]string
func (*TestIBuilderErrPref) SetEPrefStrings ¶ added in v1.6.0
func (tIBuilder *TestIBuilderErrPref) SetEPrefStrings(twoDStrArray [][2]string)
func (*TestIBuilderErrPref) String ¶ added in v1.6.0
func (tIBuilder *TestIBuilderErrPref) String() string