Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TestFuncDtoAlpha01 ¶
type TestFuncDtoAlpha01 struct {
// contains filtered or unexported fields
}
TestFuncDtoAlpha01 - This type is designed to call a series of methods using Error Prefix Data Transfer Objects otherwise known as 'ErrPrefixDto'. For source code documentation on this type, reference:
https://pkg.go.dev/github.com/MikeAustin71/errpref#ErrPrefixDto
This method chain will return an error on the last function call, if, and only if, parameter, 'returnError' is set to 'true'.
The entry point for this method chain is:
TestFuncAlpha01.Tx1DoSomething()
These examples showcase the 'ErrPrefixDto' type and the use of an empty interface to initialize a new instance of 'ErrPrefixDto'.
For source code documentation on the 'ErrPrefixDto' type, reference:
https://pkg.go.dev/github.com/MikeAustin71/errpref#ErrPrefixDto
func (*TestFuncDtoAlpha01) Tx1DoSomething ¶
func (tFuncAlpha01 *TestFuncDtoAlpha01) Tx1DoSomething( returnError bool, errorPrefix interface{}) error
type TestFuncDtoBravo01 ¶
type TestFuncDtoBravo01 struct {
// contains filtered or unexported fields
}
TestFuncDtoBravo01 - This type is designed to call a series of methods using Error Prefix Data Transfer Objects otherwise known as 'ErrPrefixDto'. For source code documentation on this type, reference:
https://pkg.go.dev/github.com/MikeAustin71/errpref#ErrPrefixDto
This method chain will return an error on the last function call, if, and only if, parameter, 'returnError' is set to 'true'.
The entry point for this method chain is:
TestFuncBravo01.Tx1DoSomethingSpecial()
These examples showcase the 'ErrPrefixDto' type and the use of an empty interface to initialize a new instance of 'ErrPrefixDto'.
func (*TestFuncDtoBravo01) Tx1DoSomethingSpecial ¶
func (tFuncDtoBravo01 *TestFuncDtoBravo01) Tx1DoSomethingSpecial( returnError bool, errorPrefix interface{}) error
type TestFuncDtoCharlie01 ¶
type TestFuncDtoCharlie01 struct {
// contains filtered or unexported fields
}
TestFuncDtoCharlie01 - This type is designed to call a series of methods using Error Prefix Data Transfer Objects otherwise known as 'ErrPrefixDto'. For source code documentation on this type, reference:
https://pkg.go.dev/github.com/MikeAustin71/errpref#ErrPrefixDto
This method chain will always return an error on the last function call.
The entry point for this method chain is:
TestFuncDtoCharlie01.Tx1DoStuff()
These examples showcase the 'ErrPrefixDto' type and the use of an empty interface to initialize a new instance of 'ErrPrefixDto'.
func (*TestFuncDtoCharlie01) Tx1DoStuff ¶
func (tFuncDtoCharlie01 *TestFuncDtoCharlie01) Tx1DoStuff( errorPrefix interface{}) error