Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TestFuncsDto ¶
type TestFuncsDto struct{}
func (TestFuncsDto) TestAlphaDto001 ¶
func (tFuncDto TestFuncsDto) TestAlphaDto001( callingMethodName string, returnError bool)
TestAlphaDto001 This method calls the Alpha Series method chain with a two-dimensional array of strings.
func (TestFuncsDto) TestAlphaDto002 ¶
func (tFuncDto TestFuncsDto) TestAlphaDto002( callingMethodName string, returnError bool)
TestAlphaDto002 This method calls the Alpha Series method chain with an ErrPrefixDto object.
func (TestFuncsDto) TestMethodSeries001 ¶
func (tFuncDto TestFuncsDto) TestMethodSeries001( callingMethodName string)
TestMethodSeries001 This method calls the Alpha, Bravo and Charlie method chains with an ErrPrefixDto object. An error is only triggered on the last method in the 'Charlie' method chain.
type TestFuncsStrings ¶
type TestFuncsStrings struct{}
TestFuncsStrings - This type includes methods designed to test the string formatting capabilities of type, 'ErrPref'.
'ErrPref' is a simple, light-weight type used to receive error prefix strings, format them and return the formatted error prefix string immediately to the caller. No error prefix information is retained or maintained in the the 'ErrPref' object. It is simply used to format strings.
func (TestFuncsStrings) TestMethodSeries001 ¶
func (tFuncStrs TestFuncsStrings) TestMethodSeries001(callingMethodName string)